agents

package
v3.0.0-alpha Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

const (
	// DefaultAppName is the default application name for the ADK runner.
	DefaultAppName = "WeOS"
)

Variables

This section is empty.

Functions

func ApplyResponseSchemaFromContext

func ApplyResponseSchemaFromContext(
	ctx agent.CallbackContext, req *model.LLMRequest,
) (*model.LLMResponse, error)

ApplyResponseSchemaFromContext is a BeforeModelCallback that applies the response schema from context (when set by RunAgent) to the LLM request so the model returns structured output.

func RunAgent

func RunAgent(
	ctx context.Context, a agent.Agent, appName, userID, sessionID, userInput string,
	responseSchema *genai.Schema, fileParts ...*genai.Part,
) (string, error)

RunAgent runs the given agent with the user input and returns the concatenated text from all non-partial LLM response events.

Types

This section is empty.

Jump to